@@ -25,7 +25,7 @@ from pymorphy2.utils import json_write, json_read
 
 logger = logging.getLogger(__name__)
 
-CURRENT_FORMAT_VERSION = '2.0'
+CURRENT_FORMAT_VERSION = '2.1'
 
 LoadedDictionary = collections.namedtuple(
     'LoadedDictionary',
@@ -154,7 +154,12 @@ def _load_tag_class(gramtab_format, grammemes_filename):
 
     grammemes = json_read(grammemes_filename)
 
-    Tag = tagset.registry[gramtab_format]
+    # clone the class
+    OriginalTag = tagset.registry[gramtab_format]
+    Tag = type(OriginalTag.__name__, (OriginalTag,), {
+        'KNOWN_GRAMMEMES': OriginalTag.KNOWN_GRAMMEMES.copy(),
+    })
+
     Tag._init_grammemes(grammemes)
 
     return Tag
